# CERES
**C**elestial **E**stimation for **R**esearch, **E**xploration, and **S**cience

- **Website:** [ceresnavigation.org](https://ceresnavigation.org)
- **Download (PyPI):** [pypi.org/project/ceres-nav](https://pypi.org/project/ceres-nav/)
- **Documentation:** [docs.ceresnavigation.org](https://docs.ceresnavigation.org)
- **Source Code:** https://github.com/ceres-navigation/ceres
- **Bug Reports:** https://github.com/ceres-navigation/ceres/issues

## Install
- **With PIP:** `pip install ceres-nav`

### Locally (for development):
*NOTE: Its recommended to create a virtual environment using mamba or conda*
- Clone repository: `git clone https://github.com/ceres-navigation/ceres`
- Install: `cd ceres; pip install -e .`

## Call for Contributions
*Coming Soon*

If you are new to contributing to open source, [this
guide](https://opensource.guide/how-to-contribute/) helps explain why, what,
and how to successfully get involved.

## Contact
All questions should be directed to Chris Gnam: crgnam@buffalo.edu
